pub struct ElfMemoryRequirements {
pub size: u64,
pub align: u64,
pub min_addr: u64,
}Expand description
Basic information about the memory segments of an elf file.
Fields
size: u64total size needed for all segments
align: u64memory alignment for the elf file
min_addr: u64the smallest virtual address used by the elf file